@@ -4,6 +4,6 @@ from macrobot import __version__
 def test_version():
     assert __version__ == '0.1.0'
 
-
-if __name__ == "__main__":
-    test_version()
\ No newline at end of file
+#
+# if __name__ == "__main__":
+#     test_version()
\ No newline at end of file
